@@ -89,6 +89,9 @@ cmd_opt		opt;			/// cmd_opt structure defined in partclone.h
 #elif EXFAT
 #include "exfatclone.h"
 #define FS "EXFAT"
+#elif MINIX
+#include "minixclone.h"
+#define FS "MINIX"
 #endif
 
 /// fs option
@@ -187,6 +190,7 @@ int main(int argc, char **argv){
     tui = open_pui(pui, opt.fresh);
     if ((opt.ncurses) && (tui == 0)){
         opt.ncurses = 0;
+	pui = TEXT;
         log_mesg(1, 0, 0, debug, "Open Ncurses User Interface Error.\n");
     }
 
@@ -621,8 +625,12 @@ int main(int argc, char **argv){
 		    /// write block from buffer to partition
 		    w_size = write_all(&dfw, cache_buffer, (image_hdr.block_size*nx_current), &opt);
 		    log_mesg(1, 0, 0, debug, "bs=%i and w=%i, ",(image_hdr.block_size*nx_current), w_size);
-		    if (w_size != (int)image_hdr.block_size*nx_current)
-			log_mesg(0, 1, 1, debug, "write error %i \n", w_size);
+		    if (w_size != (int)image_hdr.block_size*nx_current){
+			if (opt.skip_write_error == 0)
+			    log_mesg(0, 1, 1, debug, "write block %lli error %i \n", (block_id-next+1), w_size);
+			else
+			    log_mesg(0, 0, 1, debug, "skip write block %lli error %i \n", (block_id-next+1), w_size);
+		    }
 		    next = 1;
 		    next_count = next_max_count;
 		    nx_current=0;
@@ -713,15 +721,23 @@ int main(int argc, char **argv){
                 /// write buffer to target
                 w_size = write_all(&dfw, buffer, image_hdr.block_size, &opt);
                 log_mesg(3, 0, 0, debug, "bs=%i and w=%i, ",image_hdr.block_size, w_size);
-                if (w_size != (int)image_hdr.block_size)
-                    log_mesg(0, 1, 1, debug, "write error %i \n", w_size);
+		if (w_size != (int)image_hdr.block_size){
+		    if (opt.skip_write_error == 0)
+			log_mesg(0, 1, 1, debug, "write block %lli error %i \n", block_id, w_size);
+		    else
+			log_mesg(0, 0, 1, debug, "skip write block %lli error %i \n", block_id, w_size);
+		}
 
                 copied++;                                       /// count copied block
                 total_write += (unsigned long long)(w_size);    /// count copied size
                 log_mesg(2, 0, 0, debug, "total=%lli, ", total_write);
                 /// read or write error
-                if (r_size != w_size)
-                    log_mesg(0, 1, 1, debug, "read and write different\n");
+                if (r_size != w_size){
+		    if (opt.skip_write_error == 0)
+			log_mesg(0, 1, 1, debug, "read and write different\n");
+		    else
+			log_mesg(0, 0, 1, debug, "read and write different\n");
+		}
                 log_mesg(1, 0, 0, debug, "end\n");
             } else {
 #ifndef _FILE_OFFSET_BITS
